Produces one or several segregation curves, as defined in Duncan and Duncan (1955)
segcurve(data, group, unit, weight = NULL, segment = NULL)Returns a ggplot2 object.
A data frame.
A categorical variable contained in data.
Defines the first dimension over which segregation is computed.
A categorical variable contained in data.
Defines the second dimension over which segregation is computed.
Numeric. (Default NULL)
A categorical variable contained in data. (Default NULL)
If given, several segregation curves will be shown, one for each segment.